@@ -9,7 +9,8 @@ import logging
 from typing import Optional
 
 from django.conf import settings
-from django.contrib import admin, messages
+from django.contrib import admin
+from django.core.mail import EmailMultiAlternatives
 from django.db.models import QuerySet
 from django.http import HttpRequest
 from django.template.loader import render_to_string
@@ -96,9 +97,7 @@ class NotificationAdmin(admin.ModelAdmin):
         """
         return False
 
-    def has_delete_permission(
-        self, request: HttpRequest, obj: Optional[models.Notification] = None
-    ) -> bool:
+    def has_delete_permission(self, request: HttpRequest, obj: Optional[models.Notification] = None) -> bool:
         """
         Check if user has permission to delete a notification.
 
@@ -214,9 +213,7 @@ class NotificationAdmin(admin.ModelAdmin):
 
     # region Action methods
     @admin.action(description=_("Send notifications"))
-    def send_notifications(
-        self, request: HttpRequest, queryset: QuerySet[models.Notification]
-    ) -> None:
+    def send_notifications(self, request: HttpRequest, queryset: QuerySet[models.Notification]) -> None:
         """
         Re-send notifications.
 
@@ -227,22 +224,46 @@ class NotificationAdmin(admin.ModelAdmin):
         for notification in queryset:
             _sent = notification.notify(force=True)
             if _sent:
-                messages.info(
-                    request=request,
-                    message=_(
-                        "A notification has been sent for {notification}."
-                    ).format(notification=notification),
+                self.message_user(
+                    request,
+                    message=_("A notification has been sent for {notification}.").format(notification=notification),
+                    level="INFO",
                 )
             else:
-                messages.warning(
+                self.message_user(
                     request=request,
-                    message=_("No notification sent for {notification}.").format(
-                        notification=notification
-                    ),
+                    message=_("No notification sent for {notification}.").format(notification=notification),
+                    level="WARNING",
                 )
 
+    @admin.action(description=_("DEBUG - Send notification(s) to the connected user"))
+    def send_notification_to_connected_user(self, request: HttpRequest, queryset: QuerySet) -> None:
+        """
+        Send the email message to the connected user.
+
+        :param request: HTTP Request
+        :param queryset: Selected QuerySet
+        :return: Nothing
+        """
+        _user = request.user
+        sent = 0
+        for notification in queryset:
+            _email: EmailMultiAlternatives = notification.email
+            _email.to = [_user.email]
+            _email.subject = f"[DEBUG] {_email.subject}"
+            sent += _email.send(fail_silently=False)
+            self.message_user(
+                request=request,
+                message=_("DEBUG - Email notification sent for {notification} to {user}").format(
+                    notification=notification,
+                    user=_user,
+                ),
+                level="INFO",
+            )
+
     actions = [
         send_notifications,
+        send_notification_to_connected_user,
     ]
     # endregion Action methods
 
@@ -266,9 +287,7 @@ class AttachmentAdmin(admin.ModelAdmin):
         """
         return False
 
-    def has_delete_permission(
-        self, request: HttpRequest, obj: models.Attachment = None
-    ) -> bool:  # noqa
+    def has_delete_permission(self, request: HttpRequest, obj: models.Attachment = None) -> bool:  # noqa
         """
         Don't allow deleting attachments.
 
@@ -278,9 +297,7 @@ class AttachmentAdmin(admin.ModelAdmin):
         """
         return False
 
-    def has_change_permission(
-        self, request: HttpRequest, obj: models.Attachment = None
-    ) -> bool:  # noqa
+    def has_change_permission(self, request: HttpRequest, obj: models.Attachment = None) -> bool:  # noqa
         """
         Don't allow changing attachments.
 
